import { ElementRef, EventEmitter, ExistingProvider, OnChanges, OnInit, SimpleChanges, TemplateRef } from "@angular/core";
import { ControlValueAccessor } from "@angular/forms";
import { Option } from "./option";
import { OptionList } from "./option-list";
import { IOption } from "./option.interface";
import { SelectDropdownComponent } from "./select-dropdown.component";
import * as i0 from "@angular/core";
export declare const SELECT_VALUE_ACCESSOR: ExistingProvider;
export declare class SelectComponent implements ControlValueAccessor, OnChanges, OnInit {
    private hostElement;
    options: Array<IOption>;
    allowClear: boolean;
    disabled: boolean;
    multiple: boolean;
    noFilter: number;
    highlightColor: string;
    highlightTextColor: string;
    notFoundMsg: string;
    placeholder: string;
    filterPlaceholder: string;
    label: string;
    opened: EventEmitter<null>;
    closed: EventEmitter<null>;
    selected: EventEmitter<IOption>;
    deselected: EventEmitter<IOption | IOption[]>;
    focus: EventEmitter<null>;
    blur: EventEmitter<null>;
    noOptionsFound: EventEmitter<string>;
    filterInputChanged: EventEmitter<string>;
    selectionSpan: ElementRef;
    dropdown: SelectDropdownComponent;
    filterInput: ElementRef;
    optionTemplate: TemplateRef<any>;
    private _value;
    optionList: OptionList;
    hasFocus: boolean;
    isOpen: boolean;
    isBelow: boolean;
    filterEnabled: boolean;
    filterInputWidth: number;
    private isDisabled;
    placeholderView: string;
    private clearClicked;
    private selectContainerClicked;
    private optionListClicked;
    private optionClicked;
    width: number;
    top: number;
    left: number;
    private onChange;
    private onTouched;
    constructor(hostElement: ElementRef);
    /** Event handlers. **/
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
    onWindowBlur(): void;
    onWindowClick(): void;
    onWindowResize(): void;
    onSelectContainerClick(event: any): void;
    onSelectContainerFocus(): void;
    onSelectContainerKeydown(event: any): void;
    onOptionsListClick(): void;
    onDropdownOptionClicked(option: Option): void;
    onSingleFilterClick(): void;
    onSingleFilterFocus(): void;
    onFilterInput(term: string): void;
    onSingleFilterKeydown(event: any): void;
    onMultipleFilterKeydown(event: any): void;
    onMultipleFilterFocus(): void;
    onClearSelectionClick(event: any): void;
    onDeselectOptionClick(option: Option): void;
    /** API. **/
    open(): void;
    close(): void;
    clear(): void;
    select(value: string | Array<string>): void;
    /** ControlValueAccessor interface methods. **/
    writeValue(value: any): void;
    registerOnChange(fn: (_: any) => void): void;
    registerOnTouched(fn: () => void): void;
    setDisabledState(isDisabled: boolean): void;
    /** Input change handling. **/
    private handleInputChanges;
    private updateOptionList;
    private updateFilterEnabled;
    /** Value. **/
    get value(): string | string[];
    set value(v: string | string[]);
    private valueChanged;
    private updateState;
    /** Select. **/
    private selectOption;
    private deselectOption;
    private clearSelection;
    private toggleSelectOption;
    private selectHighlightedOption;
    private deselectLast;
    /** Dropdown. **/
    private toggleDropdown;
    private openDropdown;
    private closeDropdown;
    /** Filter. **/
    private filter;
    private clearFilterInput;
    private setMultipleFilterInput;
    /** Keys. **/
    private KEYS;
    private handleSelectContainerKeydown;
    private handleMultipleFilterKeydown;
    private handleSingleFilterKeydown;
    /** View. **/
    _blur(): void;
    _focus(): void;
    _focusSelectContainer(): void;
    private updateWidth;
    private updatePosition;
    private updateFilterWidth;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SelectComponent, "@firestone-hs/ng-select", never, { "options": { "alias": "options"; "required": false; }; "allowClear": { "alias": "allowClear"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "multiple": { "alias": "multiple"; "required": false; }; "noFilter": { "alias": "noFilter"; "required": false; }; "highlightColor": { "alias": "highlightColor"; "required": false; }; "highlightTextColor": { "alias": "highlightTextColor"; "required": false; }; "notFoundMsg": { "alias": "notFoundMsg"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "filterPlaceholder": { "alias": "filterPlaceholder"; "required": false; }; "label": { "alias": "label"; "required": false; }; }, { "opened": "opened"; "closed": "closed"; "selected": "selected"; "deselected": "deselected"; "focus": "focus"; "blur": "blur"; "noOptionsFound": "noOptionsFound"; "filterInputChanged": "filterInputChanged"; }, ["optionTemplate"], never, false, never>;
}
